@@ -4,29 +4,33 @@ import csv
 import os 
 
 def main():
-    jan = feb = mar = apr = may = jun = jul = aug = sep = octo = nov = dec = []
-    year = [jan, feb, mar, apr, may, jun, jul, aug, sep, octo, nov, dec]
+    January = February = March = April = May = June = July = August = September = October = November = December = []
+    year = [January, February, March, April, May, June, July, August, September, October, November, December]
+    months = ["/January", "/February", "/March", "/April", "/May", "/June", "/July", "/August", "/September", "/October", "/November", "/December"]
     for i in range(1,32):
-        jan.append(i)
-        mar.append(i)
-        may.append(i)
-        jul.append(i)
-        aug.append(i)
-        octo.append(i)
-        dec.append(i)
+        January.append(i)
+        March.append(i)
+        May.append(i)
+        July.append(i)
+        August.append(i)
+        October.append(i)
+        December.append(i)
     for i in range(1,31):
-        apr.append(i)
-        jun.append(i)
-        sep.append(i)
-        nov.append(i)
-    for i in range(1,29):
-        feb.append(i)
+        April.append(i)
+        June.append(i)
+        September.append(i)
+        November.append(i)
+    for i in range(1,30):
+        February.append(i)
     lengths = {1:31, 2:28, 3:31, 4:30, 5:31, 6:30, 7:31, 8:31, 9:30, 10:31, 11:30, 12:31}
 
     if os.path.isdir("./Stat_Sheets") == False:
         os.mkdir("./Stat_Sheets")
     
     for z in range(1,len(year) + 1):
+        folder = months[z - 1]
+        if os.path.isdir("./Stat_Sheets" + folder) == False:
+            os.mkdir("./Stat_Sheets" + folder)
         for w in range(1, lengths[z] + 1):
             my_url = "http://rotoguru1.com/cgi-bin/hyday.pl?game=fd&mon=" + str(z) + "&day=" + str(w) + "&year=2019" #bs4 setup stuff
             uClient = uReq(my_url)
@@ -61,8 +65,7 @@ def main():
                         playerTrackeer = i + 2
                         break
 
-
-                filename = "Stat_Sheets/NBAFanduel(" + str(z) + "." + str(w) + ").csv"    
+                filename = "Stat_Sheets/" + folder + "/" + str(z) + "-" + str(w) + "-2019.csv"
                 with open(filename, "w", newline="") as csvfile: # writing to csv file  
                     csvwriter = csv.writer(csvfile)  
                     csvwriter.writerow(fields)  
